Trait ipfs_api::request::ApiRequest
[−]pub trait ApiRequest: Serialize + Send {
const PATH: &'static str;
const METHOD: Method = ;
fn absolute_url(&self, base: &Uri) -> Result<Uri, Error> { ... }
}Expand description
A request that can be made against the Ipfs API.
Required Associated Constants
Provided Associated Constants
Provided Methods
fn absolute_url(&self, base: &Uri) -> Result<Uri, Error>
fn absolute_url(&self, base: &Uri) -> Result<Uri, Error>
Creates the absolute URL for an API resource given the base path of the service.